{#- OZI 0.1
# ozi/templates/github_workflows/publish.yml
# Part of the OZI Project, under the Apache License v2.0 with LLVM Exceptions.
# See LICENSE.txt for license information.
# SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
#}
  publish:
    runs-on: ubuntu-latest
    needs: release
    if: needs.release.outputs.drafted == 'true'
    permissions:
      contents: write
      id-token: write
    steps:
    - uses: rjdbcm/ozi-publish@v{{ spec.version }}
      with:
{%- raw %}
        github-token: ${{ secrets.GITHUB_TOKEN }}
{%- endraw %}
