{#- OZI 0.1
# ozi/templates/github_workflows/checkpoint.yml.j2
# Part of the OZI Project, under the Apache License v2.0 with LLVM Exceptions.
# See LICENSE.txt for license information.
# SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-#}
  checkpoint:
{%- raw %}
    name: OZI ${{ matrix.ozi }} with ${{ matrix.py }} on ${{ matrix.os }}
    runs-on: '${{ matrix.os }}'
{%- endraw %}
    strategy:
      matrix:
        ozi:
{%- for suite in spec.python.ci.checkpoint.suites %}
          - {{ suite }}
{%- endfor %}
        os:
          - ubuntu-latest
        py:
          - {{ spec.python.support.security }}
          - {{ spec.python.support.bugfix2 }}
          - {{ spec.python.support.bugfix1 }}
      fail-fast: false
    steps:
      - uses: actions/checkout@v4
        with:
          fetch-depth: 0

      - uses: rjdbcm/ozi-checkpoint@v{{ spec.version }}
        with:
{%- raw %}
          python-version: ${{ matrix.py }}
          suite: ${{ matrix.ozi }}
{%- endraw %}
